pub struct DeleteModelRequest {
pub model_name: String,
pub provider: i32,
}Expand description
Request to delete a model record from the registry
Fields
model_name: Stringprovider: i32Implementations
Sourceimpl DeleteModelRequest
impl DeleteModelRequest
Sourcepub fn provider(&self) -> ModelProvider
pub fn provider(&self) -> ModelProvider
Returns the enum value of provider, or the default if the field is set to an invalid enum value.
Sourcepub fn set_provider(&mut self, value: ModelProvider)
pub fn set_provider(&mut self, value: ModelProvider)
Sets provider to the provided enum value.