pub struct ModelDownloadRequest {
pub model_name: String,
pub provider: i32,
pub ignore_weights: bool,
}Expand description
Request to ensure a model is downloaded
Fields
model_name: Stringprovider: i32ignore_weights: boolImplementations
Sourceimpl ModelDownloadRequest
impl ModelDownloadRequest
Sourcepub fn provider(&self) -> ModelProvider
pub fn provider(&self) -> ModelProvider
Returns the enum value of provider, or the default if the field is set to an invalid enum value.
Sourcepub fn set_provider(&mut self, value: ModelProvider)
pub fn set_provider(&mut self, value: ModelProvider)
Sets provider to the provided enum value.