pub struct ModelFilesRequest {
pub model_name: String,
pub provider: i32,
pub chunk_size: u32,
}Expand description
Request for streaming model files
Fields
model_name: StringThe name of the model to stream
provider: i32The provider of the model
chunk_size: u32Chunk size in bytes for streaming (0 = use server default)
Implementations
Sourceimpl ModelFilesRequest
impl ModelFilesRequest
Sourcepub fn provider(&self) -> ModelProvider
pub fn provider(&self) -> ModelProvider
Returns the enum value of provider, or the default if the field is set to an invalid enum value.
Sourcepub fn set_provider(&mut self, value: ModelProvider)
pub fn set_provider(&mut self, value: ModelProvider)
Sets provider to the provided enum value.