pub struct ModelStatusUpdate {
pub model_name: String,
pub status: i32,
pub message: Option<String>,
pub provider: i32,
}Expand description
Streaming status update for model download progress
Fields
model_name: Stringstatus: i32message: Option<String>Optional message for additional context (e.g., progress info, error details)
provider: i32Implementations
Sourceimpl ModelStatusUpdate
impl ModelStatusUpdate
Sourcepub fn status(&self) -> ModelStatus
pub fn status(&self) -> ModelStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ModelStatus)
pub fn set_status(&mut self, value: ModelStatus)
Sets status to the provided enum value.
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Returns the value of message, or the default value if message is unset.
Sourcepub fn provider(&self) -> ModelProvider
pub fn provider(&self) -> ModelProvider
Returns the enum value of provider, or the default if the field is set to an invalid enum value.
Sourcepub fn set_provider(&mut self, value: ModelProvider)
pub fn set_provider(&mut self, value: ModelProvider)
Sets provider to the provided enum value.