Modules
- cache
- client_
config - config
- constants
- Constants shared between client and server
- download
- grpc
- models
- providers
Structs
- Response
- Defines the shared response format between server and client (legacy HTTP)
- Utils
- Marker struct to use Utils methods
Enums
- Error
- Common error types that both client and server can use
Type Aliases
- Result
- Common result type for the project